<?php
/**
 * Defining package.
 *
 *  @package : addify_quick_order_table
 */

if ( ! defined( 'ABSPATH' ) ) {
		exit;
}

/**
 * Creating Class.
 */
class Addify_Qof_Admin {

	/**
	 * Constructor.
	 */
	public function __construct() {

		add_action( 'admin_enqueue_scripts', array( $this, 'qof_admin_enqueue_scripts' ) );
		add_filter( 'post_row_actions', array( $this, 'addify_remove_post_actions' ), 10, 1 );
		add_action( 'init', array( $this, 'addify_qof_post_type' ) );
		add_action( 'admin_menu', array( $this, 'addify_qof_submenu' ) );
		add_action( 'add_meta_boxes', array( $this, 'addify_form_setting_metabox' ) );
		add_action( 'add_meta_boxes', array( $this, 'addify_form_permissions_metabox' ) );
		add_action( 'add_meta_boxes', array( $this, 'addify_product_chosen_metabox' ) );
		add_action( 'save_post', array( $this, 'qof_update_metadata' ) );
		add_action( 'add_meta_boxes', array( $this, 'addify_display_table_metabox' ) );

		add_action( 'wp_ajax_addify_search_products', array( $this, 'addify_search_products' ) );
		add_action( 'wp_ajax_nopriv_addify_search_products', array( $this, 'addify_search_products' ) );

		add_action( 'wp_ajax_addify_search_customer', array( $this, 'addify_search_customer' ) );
		add_action( 'wp_ajax_nopriv_addify_search_customer', array( $this, 'addify_search_customer' ) );
	}
	
	/**
	 * Including css and javascript.
	 */
	public function qof_admin_enqueue_scripts() {
		$screen = get_current_screen();
		if ( 'orderform' === $screen->id  ) {

		wp_enqueue_style( 'qof_admin_style', plugins_url( 'assets/css/addify_qof_admin_style.css', __FILE__ ), false, '1.0.0' );
		wp_enqueue_script( 'qof_admin_js', plugins_url( 'assets/js/addify_qof_admin_js.js', __FILE__ ), array( 'jquery' ), '1.0.0', false );
		wp_enqueue_style( 'qof_admin_select2_style', plugins_url( 'assets/css/select2.css', __FILE__ ), false, '1.0.0' );
		wp_enqueue_script( 'qof_admin_select2_js', plugins_url( 'assets/js/select2.js', __FILE__ ), array( 'jquery' ), '1.0.0', false );
		$addify_qof_ajax_data = array(
			'admin_url' => admin_url( 'admin-ajax.php' ),
			'nonce'     => wp_create_nonce( 'quick_order_nonce' ),
		);
		wp_localize_script( 'qof_admin_js', 'addify_qof_search_var', $addify_qof_ajax_data );
	}
}

	/**
	 * Adding Sub Menu.
	 */
	public function addify_qof_submenu() {

		add_submenu_page(
			'woocommerce',
			__( 'Quick Order Tables', 'qof_form_order' ),
			__( 'Quick Order Tables', 'qof_form_order' ),
			'manage_options',
			'edit.php?post_type=orderform',
			'',
			5
		);
	}
	/**
	 * Creating addify_remove_post_actions.
	 *
	 * @param int $actions First argument.
	 */
	public function addify_remove_post_actions( $actions ) {
			unset( $actions['inline hide-if-no-js'] );
			return $actions;
	}
	/**
	 * Making setting page.
	 */
	public function addify_qof_post_type() {

		$label = array(
			'name'          => esc_html__( 'Quick Order Tables', 'qof_form_order' ),
			'singular_name' => esc_html__( 'Quick Order Tables', 'qof_form_order' ),
			'add_new'       => esc_html__( 'Create Table', 'qof_form_order' ),
			'search_items'  => esc_html__( 'Search Rule', 'qof_form_order' ),
		);
		$args  = array(
			'labels'              => $label,
			'public'              => true,
			'has_archives'        => true,
			'publicly_queryable'  => false,
			'query_var'           => true,
			'hierarchical'        => false,
			'capability_type'     => 'post',
			'show_in_menu'        => false,
			'supports'            => array(
				'title',
			),
			'exclude_from_search' => false,
		);
		register_post_type( 'orderform', $args );
	}

	/**
	 * Creating addify_form_setting_metabox.
	 */
	public function addify_form_setting_metabox() {

		add_meta_box( 'addify_form_meta', esc_html__( ' Table Settings', 'qof_form_order' ), array( $this, 'addify_form_setting' ), 'orderform', 'normal', 'high' );
	}
	/**
	 * Creating addify_form_setting.
	 *
	 * @param int $post First argument.
	 */
	public function addify_form_setting( $post ) {
		$qof_rule_status = $post->post_status;
		$qof_per_page    = get_post_meta( get_the_ID(), 'qof_enable_pagination', true );
		$qof_quantity    = get_post_meta( get_the_ID(), 'qof_product_quantity', true );
		if ( 'publish' === $qof_rule_status ) {
			$custom_meta = json_decode( get_post_meta( get_the_ID(), '_custom_meta_product_info', true ) );
		} else {
			$custom_meta = array( 'sku', 'price', 'thumbnail', 'num_product' );
		}
		if ( 'publish' === $qof_rule_status ) {

			$custom_filters = json_decode( get_post_meta( get_the_ID(), '_custom_search_filters_info', true ) );

		} else {

			$custom_filters = array( 'product_filter', 'tag_filter', 'category_filter', 'sku_filter' );
		}
		?>
<table class="qof_rule_meta">
<tr>
	<th>
		<h3><?php echo( esc_html__( ' Disable Pagination', 'qof_form_order' ) ); ?></h3>
	</th>
	<td class='add_qof'><input type="checkbox" name="qof_pagiantion" id="qof_pagiantion" value="yes"
		<?php
		if ( 'yes' === get_post_meta( get_the_ID(), 'qof_pagiantion', true ) ) {
			echo 'checked'; }
		?>
		><?php echo esc_html__( ' Disable Pagination', 'qof_form_order' ); ?>
		<br>
		<label>Check to disable the pagination.</label>
		<br><br>
	</td>
</tr>
<tr class='hide_pagination_div'>
	<th><h3 for="quantity"><?php echo( esc_html__( 'Pagination', 'qof_form_order' ) ); ?></h3></th>
		<?php
		if ( empty( $qof_per_page ) ) {
			?>
		<td class='add_qof'><input type="number" name="qof_enable_pagination" min="1" value= "10">
		<br>
		<label><?php echo( esc_html__( ' Enter the Number of products per page. Default is set to 10 products per page.', 'qof_form_order' ) ); ?></label>
		<br><br>
		</td> 
			<?php
		} else {
			?>
		<td class='add_qof'><input type="number" name="qof_enable_pagination" min="1" value= "<?php echo esc_html( $qof_per_page ) ? esc_html( $qof_per_page ) : 0; ?>">
			<br>
			<label><?php echo( esc_html__( ' Enter the Number of products per page. Default is set to 10 products per page.', 'qof_form_order' ) ); ?></label>
			<br><br>
			</td>
			<?php
		}
		?>
</tr>
<tr>
	<th>
		<h3>
			<?php esc_html_e( 'Choose Table Columns to Show' , 'qof_form_order' ); ?>
		</h3>
	</th>
	<td class='add_qof'>
		<input type="checkbox" name="custom_meta_product_info[]" value="sku" <?php echo ( in_array( 'sku', (array) $custom_meta, true ) ) ? 'checked="checked"' : ''; ?> 
		><?php echo '       '; ?><label><?php esc_html_e( 'SKU' , 'qof_form_order' ); ?></label>
		<br>
		<input type="checkbox" name="custom_meta_product_info[]" value="thumbnail" <?php echo ( in_array( 'thumbnail', (array) $custom_meta, true ) ) ? 'checked="checked"' : ''; ?> 
		><?php echo '       '; ?><label><?php esc_html_e( 'Product Image' , 'qof_form_order'); ?></label>
		<br>
		<input type="checkbox" name="custom_meta_product_info[]" value="price" <?php echo ( in_array( 'price', (array) $custom_meta, true ) ) ? 'checked="checked"' : ''; ?> 
		><?php echo '       '; ?><label><?php esc_html_e( 'Price', 'qof_form_order' ); ?></label>
		<br>
		<input type="checkbox" name="custom_meta_product_info[]" value="num_product" <?php echo ( in_array( 'num_product', (array) $custom_meta, true ) ) ? 'checked="checked"' : ''; ?> 
		><?php echo '       '; ?><label><?php esc_html_e( 'Show Number of Products' , 'qof_form_order'); ?></label>
		<br>
		<input type="checkbox" name="custom_meta_product_info[]" value="description" <?php echo ( in_array( 'description', (array) $custom_meta, true ) ) ? 'checked="checked"' : ''; ?> 
		><?php echo '       '; ?><label><?php esc_html_e( 'Product Description' , 'qof_form_order'); ?></label>
		<br>
		<input type="checkbox" name="custom_meta_product_info[]" value="rating" <?php echo ( in_array( 'rating', (array) $custom_meta, true ) ) ? 'checked="checked"' : ''; ?> 
		><?php echo '       '; ?><label><?php esc_html_e( 'Product Rating' , 'qof_form_order'); ?></label>
		<br>
		<label><?php echo( esc_html__( 'Select the column to show in table. Default all columns are showing.', 'qof_form_order' ) ); ?></label>
		<br><br>
	</td>
</tr>
<tr>
	<th>
		<h3>
			<?php esc_html_e( 'Choose Search Filters to Show' , 'qof_form_order'); ?>
		</h3>
	</th>
	<td>
	<input type="checkbox" name="custom_search_filters_info[]" value="product_filter" <?php echo ( in_array( 'product_filter', (array) $custom_filters, true ) ) ? 'checked="checked"' : ''; ?> 
		><label><?php esc_html_e( 'Product Filter' , 'qof_form_order'); ?></label>
		<br>
		<input type="checkbox" name="custom_search_filters_info[]" value="category_filter" <?php echo ( in_array( 'category_filter', (array) $custom_filters, true ) ) ? 'checked="checked"' : ''; ?> 
		><label><?php esc_html_e( 'Category Filter' , 'qof_form_order'); ?></label>
		<br>
		<input type="checkbox" name="custom_search_filters_info[]" value="tag_filter" <?php echo ( in_array( 'tag_filter', (array) $custom_filters, true ) ) ? 'checked="checked"' : ''; ?> 
		><label><?php esc_html_e( 'Tag Filter' , 'qof_form_order'); ?></label>
		<br>
		<input type="checkbox" name="custom_search_filters_info[]" value="sku_filter" <?php echo ( in_array( 'sku_filter', (array) $custom_filters, true ) ) ? 'checked="checked"' : ''; ?> 
		><label><?php esc_html_e( 'SKU Filter' , 'qof_form_order'); ?></label>
		<br>
		<label><?php echo( esc_html__( ' Select filters to show. Default all filters are showing.', 'qof_form_order' ) ); ?></label>
		<br><br>
	</td>
</tr>
<tr>
	<th>
		<h3><?php esc_html_e( 'Show Add to Cart Button' , 'qof_form_order'); ?></h3>
	</th>
	<td class='add_qof'>
		<?php
		if ( 'publish' === $qof_rule_status ) {
			?>
		<input type="checkbox" name="qof_single_cart" id="qof_single_cart" value="yes"
			<?php
			if ( 'yes' === get_post_meta( get_the_ID(), 'qof_single_cart', true ) ) {
				echo 'checked'; }
		} else {
			?>
			<input type="checkbox" name="qof_single_cart" id="qof_single_cart" checked  value="yes">
			<?php
		}
		?>
		<label><?php echo ( esc_html__( 'Individual Add to Cart Button' , 'qof_form_order' ) ); ?></label>
		<br>
		<?php
		if ( 'publish' === $qof_rule_status ) {
			?>
		<input type="checkbox" name="qof_bottom_cart" id="qof_bottom_cart" value="yes"
			<?php
			if ( 'yes' === get_post_meta( get_the_ID(), 'qof_bottom_cart', true ) ) {
				echo 'checked'; }
		} else {
			?>
			<input type="checkbox" name="qof_bottom_cart" id="qof_bottom_cart" checked value="yes">
			<?php
		}
		?>
		<label><?php echo( esc_html__('Bottom Bulk Add to Cart Button' , 'qof_form_order' ) ); ?></label>
		<br>
		<label><?php echo( esc_html__(' Select the buttons to show or hide. Default both are showing.', 'qof_form_order') ); ?></label>
		<br><br>
	</td>
</tr>
</table>
		<?php
	}
	/**
	 * Creating addify_form_permissions_metabox.
	 */
	public function addify_form_permissions_metabox() {

		add_meta_box( 'addify_form_permission_meta', 'Form Permissions', array( $this, 'addify_form_permission_setting' ), 'orderform', 'normal', 'high' );
	}
	/**
	 * Creating addify_form_permission_setting.
	 *
	 * @param int $post First argument.
	 */
	public function addify_form_permission_setting( $post ) {
		$qof_rule_status = $post->post_status;
		$values          = get_post_meta( get_the_ID(), 'qof_addify_roles_checkbox', true );
		$values          = json_decode( $values );;
		?>
		<table class="qof_rule_meta">
		<tr>
			<th style="vertical-align: top;">
				<h3><?php esc_html_e( 'All Roles' , 'qof_form_order' ); ?></h3>
			</th>

			<td class='add_qof'>
				<?php
				if ( 'publish' === $qof_rule_status ) {
					?>
				<input type="checkbox" name="qof_all_roles" id="qof_all_roles" value="yes"
					<?php
					if ( 'yes' === get_post_meta( get_the_ID(), 'qof_all_roles', true ) ) {
						echo 'checked'; }
				} else {
					?>
					<input type="checkbox" name="qof_all_roles" id="qof_all_roles" checked value="yes">
					<?php
				}
				?>
				<label><?php esc_html_e( 'Allow All Roles' , 'qof_form_order' ); ?></label>
			</td>
		</tr>
		<tr class="qof_roles_hide_div">
			<th style="vertical-align: top;">
		    <h3><?php esc_html_e( 'User Roles', 'qof_form_order' ); ?></h3>
		</th>
		<td>
		    <?php
		    global $wp_roles;
		    $roles = $wp_roles->get_names();
		    ?>
		    <select name="qof_addify_roles_select[]" class="qof_user_role" multiple="multiple" placeholder="user" id="roles-select" style="width: 100%;">
		        <!-- Hidden placeholder option -->
		        <option value="" disabled hidden></option>
		        <?php foreach ( $roles as $key => $value ) : ?>
		            <option value="<?php echo esc_attr( $key ); ?>" 
		                <?php echo in_array( (string) $key, (array) $values, true ) ? 'selected' : ''; ?>>
		                <?php echo esc_html( $value ); ?>
		            </option>
		        <?php endforeach; ?>
		        <option value="log_out" 
		            <?php echo in_array( 'log_out', (array) $values, true ) ? 'selected' : ''; ?>>
		            <?php esc_html_e( 'Guest Users', 'qof_form_order' ); ?>
		        </option>
		   

		    </select>
		    <?php wp_nonce_field( 'checkbox_nonce_action', 'checkbox_fields_nonce' ); ?>
		</td>
		</tr>

		<tr class="qof_roles_hide_div">
			<th><h3><?php echo( esc_html__( 'Choose Specific Users', 'qof_form_order' ) ); ?></h3></th>
			<td >
			<select class="qof_search_customers" name="qof_search_customers[]" data-placeholder="<?php echo( esc_html__('Select Customers...' , 'qof_form_order') ); ?>" multiple style="width: 450px;">
				<?php
				global $post;
				$selected_customer = json_decode( get_post_meta( $post->ID, 'qof_search_customers', true ) );
				if ( ! empty( $selected_customer ) && is_array( $selected_customer ) ) {
					foreach ( (array) $selected_customer as $qof_usr ) {
						$qof_author_obj = get_user_by( 'id', $qof_usr );
						if ( ! is_object( $qof_author_obj ) ) {
							continue;
						}
						?>
					<option value="<?php echo intval( $qof_usr ); ?>" selected="selected">
						<?php /* translators: %s: Customer full email */ ?>
						<?php echo esc_html__($qof_author_obj->user_email , 'qof_form_order'); ?></option>
						<?php
					}
				}
				?>
			</select>
		</td>
		</tr>
		<tr>
			<td></td>
			<td><label><?php echo( esc_html__( 'Select roles/customers for which to create rule.', 'qof_form_order' ) ); ?></label></td>
		</tr>
		</div>
		</table>
		<?php
	}
	/**
	 * Creating addify_product_chosen_metabox.
	 */
	public function addify_product_chosen_metabox() {

		add_meta_box( 'addify_product_chosen_meta', 'Choose Product', array( $this, 'addify_product_choosen_setting' ), 'orderform', 'normal', 'high' );
	}
	/**
	 * Creating addify_product_choosen_setting.
	 */
	public function addify_product_choosen_setting() {
		global $post;
		$selected_products = json_decode( get_post_meta( $post->ID, 'qof_search_product', true ) );
		?>
		<table class="qof_rule_meta">
		<tr>
			<th>
				<h3><?php esc_html_e( 'Product' , 'qof_form_order'); ?></h3>
			</th>
			<td class='add_qof'><input type="checkbox" name="qof_all_pro" id="qof_all_product" value="yes"
				<?php
				if ( 'yes' === get_post_meta( get_the_ID(), 'qof_all_pro', true ) ) {
					echo 'checked'; }
				?>
				>
			<label><?php esc_html_e( 'Check to show all products.', 'qof_form_order'); ?></label>
			</td>
		</tr>
		<tr class="qof_product_div">
			<th>
				<h3><?php esc_html_e( 'Specific Product' , 'qof_form_order' ); ?></h3>
			</th>
			<td>
			<select class="qof_search_product" name="qof_search_product[]" multiple style="width: 450px;">
				<?php
				foreach ( (array) $selected_products as $value ) {
					if ( $value ) {
						$product = wc_get_product( $value );
						?>
				<option value="<?php echo esc_attr( $value ); ?>" selected>
						<?php /* translators: %s: Customer full email */ ?>
						<?php echo esc_html__($product->get_name(), 'qof_form_order' ); ?>
						<?php
					}
				}
				?>
			</select>
			<br><br>
		</td></tr>
		<tr class="qof_product_div">
			<th>
			<h3><?php esc_html_e( 'Specific Categories' , 'qof_form_order' ); ?></h3>
			</th>
				<td class="add_qof">
				<?php
				$orderby    = 'name';
				$order      = 'asc';
				$hide_empty = false;
				$cat_args   = array(
					'orderby'    => $orderby,
					'order'      => $order,
					'hide_empty' => $hide_empty,
				);

				$product_categories = get_terms( 'product_cat' );
				global $post;
				$selected_categories = json_decode( get_post_meta( $post->ID, 'qof_search_category', true ) );
				$selected_categories = is_array( $selected_categories ) ? $selected_categories : array();
				?>
				<select class="qof_search_category" data-placeholder= "<?php esc_html_e('Choose Categories...' , 'qof_form_order'); ?>" tabindex="-1" name="qof_search_category[]" multiple
						style="width: 450px;">
					<?php
					foreach ( $product_categories  as $product_category ) {
						?>
						<option value="<?php echo esc_html( $product_category->term_id ); ?>"
						<?php
						if ( in_array( (string) $product_category->term_id, (array) $selected_categories, true ) ) {
							echo 'selected'; }
						?>
							>
							<?php /* translators: %s: Customer full email */ ?>
							<?php echo esc_html__($product_category->name , 'qof_form_order' ); ?>
						</option>
						<?php
					}
					?>
				</select>
				<br><br>
				</td>
			</tr>						
		<tr class="qof_product_div">
			<th>
			<h3>Specific Tags</h3>
		</th>
			<td class="add_qof">
					<?php
					$args         = array(
						'hide_empty' => false,
					);
					$product_tags = get_terms( 'product_tag' );
					global $post;
					$selected_tags = json_decode( get_post_meta( $post->ID, 'qof_search_tag', true ) );
					$selected_tags = is_array( $selected_tags ) ? $selected_tags : array();
					?>
				<select class="qof_search_tag" name="qof_search_tag[]" data-placeholder="<?php esc_html_e('Choose Tags...' , 'qof_form_order'); ?>" multiple style="width: 450px;">
				?>
					<?php
					global $post;
					foreach ( $product_tags as $product_tag ) {
						?>
				<option value="<?php echo esc_html( $product_tag->term_id ); ?>"
						<?php
						if ( in_array( (string) $product_tag->term_id, (array) $selected_tags, true ) ) {
							echo 'selected'; }
						?>
						>
							<?php /* translators: %s: Customer full email */ ?>
							<?php echo esc_html__($product_tag->name , 'qof_form_order' ); ?>
					</option>
						<?php
					}
					?>
				</select>
			</td>
		</tr>
		<tr class="qof_product_div">
			<td></td>
		<td><label><?php echo( esc_html__( ' Select product, category and tag. Default all products,category and tags are showing.', 'qof_form_order' ) ); ?><label></td>
		</tr>
		</table>
		<?php
	}
	/**
	 * Creating qof_update_metadata.
	 *
	 * @param int $post_id First argument.
	 */
	public function qof_update_metadata( $post_id ) {
		global $post;
		if ( isset( $_POST['qof_form_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['qof_form_nonce'], 'qof_form_nonce_action' ) ) ) ) {
			print 'Sorry, your nonce did not verify.';
			exit;
		}

		if ( isset( $_POST['qof_pagiantion'] ) ) {

			$qof_pagiantion = sanitize_meta( '', wp_unslash( $_POST['qof_pagiantion'] ), '' );
		}

		if ( isset( $qof_pagiantion ) ) {
			update_post_meta( $post_id, 'qof_pagiantion', $qof_pagiantion );
		} else {
			update_post_meta( $post_id, 'qof_pagiantion', '' );
		}

		if ( isset( $_POST['qof_enable_pagination'] ) ) {

			$qof_enable_pagination = sanitize_meta( '', wp_unslash( $_POST['qof_enable_pagination'] ), '' );
		}

		if ( isset( $qof_enable_pagination ) ) {
			update_post_meta( $post_id, 'qof_enable_pagination', $qof_enable_pagination );
		} else {
			update_post_meta( $post_id, 'qof_enable_pagination', '' );
		}

		if ( isset( $_POST['qof_product_quantity'] ) ) {
			$qof_product_quantity = sanitize_text_field( wp_unslash( $_POST['qof_product_quantity'] ) );
			update_post_meta( $post_id, 'qof_product_quantity', $qof_product_quantity );
		} else {
			update_post_meta( $post_id, 'qof_product_quantity', '' );
		}
		if ( isset( $_POST['qof_single_cart'] ) ) {
			$qof_single_cart = sanitize_text_field( wp_unslash( $_POST['qof_single_cart'] ) );
			update_post_meta( $post_id, 'qof_single_cart', $qof_single_cart );
		} else {
			update_post_meta( $post_id, 'qof_single_cart', '' );
		}
		if ( isset( $_POST['qof_top_cart'] ) ) {

			$qof_top_cart = sanitize_text_field( wp_unslash( $_POST['qof_top_cart'] ) );
			update_post_meta( $post_id, 'qof_top_cart', $qof_top_cart );
		} else {
			update_post_meta( $post_id, 'qof_top_cart', '' );
		}
		if ( isset( $_POST['qof_bottom_cart'] ) ) {
			$qof_bottom_cart = sanitize_text_field( wp_unslash( $_POST['qof_bottom_cart'] ) );
			update_post_meta( $post_id, 'qof_bottom_cart', $qof_bottom_cart );
		} else {
			update_post_meta( $post_id, 'qof_bottom_cart', '' );
		}
		if ( isset( $_POST['qof_all_roles'] ) ) {
			$qof_all_roles = sanitize_text_field( wp_unslash( $_POST['qof_all_roles'] ) );
			update_post_meta( $post_id, 'qof_all_roles', $qof_all_roles );
		} else {
			update_post_meta( $post_id, 'qof_all_roles', '' );
		}
		if ( isset( $_POST['qof_all_pro'] ) ) {
			$qof_all_product = sanitize_text_field( wp_unslash( $_POST['qof_all_pro'] ) );
			update_post_meta( $post_id, 'qof_all_pro', $qof_all_product );
		} else {
			update_post_meta( $post_id, 'qof_all_pro', '' );
		}

		if ( isset( $_POST['qof_search_product'] ) ) {

			$value = sanitize_meta( '', wp_unslash( $_POST['qof_search_product'] ), '' );
		}

		if ( isset( $value ) ) {
			update_post_meta( $post_id, 'qof_search_product', wp_json_encode( $value ) );
		} else {
			update_post_meta( $post_id, 'qof_search_product', wp_json_encode( array() ) );
		}

		if ( isset( $_POST['qof_search_category'] ) ) {

			update_post_meta( $post_id, 'qof_search_category', wp_json_encode( sanitize_meta( '', wp_unslash( $_POST['qof_search_category'] ), '' ) ) );
		} else {
			update_post_meta( $post_id, 'qof_search_category', wp_json_encode( array() ) );
		}
		if ( isset( $_POST['qof_search_tag'] ) ) {

			update_post_meta( $post_id, 'qof_search_tag', wp_json_encode( sanitize_meta( '', wp_unslash( $_POST['qof_search_tag'] ), '' ) ) );
		} else {
			update_post_meta( $post_id, 'qof_search_tag', wp_json_encode( array() ) );
		}

		if ( isset( $_POST['qof_search_customers'] ) ) {

			$value = sanitize_meta( '', wp_unslash( $_POST['qof_search_customers'] ), '' );
		}

		if ( isset( $value ) ) {
			update_post_meta( $post_id, 'qof_search_customers', wp_json_encode( $value ) );
		} else {
			update_post_meta( $post_id, 'qof_search_customers', wp_json_encode( array() ) );
		}

	if ( isset( $_POST['qof_addify_roles_select'] ) ) {

			$value = sanitize_meta( '', wp_unslash( $_POST['qof_addify_roles_select'] ), '' );
		}

		if ( isset( $value ) ) {
			update_post_meta( $post_id, 'qof_addify_roles_select', wp_json_encode( $value ) );
		} else {
			update_post_meta( $post_id, 'qof_addify_roles_select', wp_json_encode( array() ) );
		}

		if ( isset( $_POST['qof_addify_roles_checkbox'] ) ) {

			$value = sanitize_meta( '', wp_unslash( $_POST['qof_addify_roles_checkbox'] ), '' );
		}

		if ( isset( $value ) ) {
			update_post_meta( $post_id, 'qof_addify_roles_checkbox', wp_json_encode( $value ) );
		} else {
			update_post_meta( $post_id, 'qof_addify_roles_checkbox', wp_json_encode( array() ) );
		}

		if ( isset( $_POST['custom_search_filters_info'] ) ) {

			$value = sanitize_meta( '', wp_unslash( $_POST['custom_search_filters_info'] ), '' );
		}

		if ( isset( $value ) ) {
			update_post_meta( $post_id, '_custom_search_filters_info', wp_json_encode( $value ) );
		} else {
			update_post_meta( $post_id, '_custom_search_filters_info', wp_json_encode( array() ) );
		}

		if ( isset( $_POST['custom_meta_product_info'] ) ) {

			$value = sanitize_meta( '', wp_unslash( $_POST['custom_meta_product_info'] ), '' );
		}

		if ( isset( $value ) ) {
			update_post_meta( $post_id, '_custom_meta_product_info', wp_json_encode( $value ) );
		} else {
			update_post_meta( $post_id, '_custom_meta_product_info', wp_json_encode( array() ) );
		}
	}

	/**
	 * Creating addify_search_products.
	 */
	public function addify_search_products() {

		$nonce = isset( $_POST['nonce'] ) && '' !== $_POST['nonce'] ? sanitize_text_field( wp_unslash( $_POST['nonce'] ) ) : 0;
		if ( isset( $_POST['q'] ) && '' !== $_POST['q'] ) {
			if ( ! wp_verify_nonce( $nonce, 'quick_order_nonce' ) ) {
				die( 'Failed ajax security check!' );
			}
			$pro = sanitize_text_field( wp_unslash( $_POST['q'] ) );
		} else {
			$pro = '';
		}
		$data_array = array();
		$args       = array(
			'post_type'   => array( 'product' ),
			'post_status' => 'publish',
			'numberposts' => -1,
			's'           => $pro,
		);
		$pros       = get_posts( $args );
		if ( ! empty( $pros ) ) {
			foreach ( $pros as $proo ) {
				$title        = ( mb_strlen( $proo->post_title ) > 50 ) ? mb_substr( $proo->post_title, 0, 49 ) . '...' : $proo->post_title;
				$data_array[] = array( $proo->ID, $title ); // array( Post ID, Post Title ).
			}
		}
		echo wp_json_encode( $data_array );
		die();
	}


	/**
	 * Creating addify_search_customer.
	 */
	public function addify_search_customer() {

		$nonce = isset( $_POST['nonce'] ) && '' !== $_POST['nonce'] ? sanitize_text_field( wp_unslash( $_POST['nonce'] ) ) : 0;
		if ( isset( $_POST['q'] ) && '' !== $_POST['q'] ) {
			if ( ! wp_verify_nonce( $nonce, 'quick_order_nonce' ) ) {
				die( 'Failed ajax security check!' );
			}
			$pro = sanitize_text_field( wp_unslash( $_POST['q'] ) );
		} else {
			$pro = '';
		}
		$data_array  = array();
		$users       = new WP_User_Query(
			array(
				'search'         => '*' . esc_attr( $pro ) . '*',
				'search_columns' => array(
					'user_login',
					'user_nicename',
					'user_email',
					'user_url',
				),
			)
		);
		$users_found = $users->get_results();
		if ( ! empty( $users_found ) ) {
			foreach ( $users_found as $proo ) {
				$title        = $proo->display_name . '(' . $proo->user_email . ')';
				$data_array[] = array( $proo->ID, $title ); // array( User ID, User name and email ).
			}
		}
		echo wp_json_encode( $data_array );
		die();
	}
	/**
	 * Creating addify_display_table_metabox.
	 */
	public function addify_display_table_metabox() {

		add_meta_box( 'addify_shortcode_meta', 'ShortCode', array( $this, 'addify_shortcode_setting' ), 'orderform', 'normal', 'high' );
	}
	/**
	 * Creating addify_shortcode_setting.
	 *
	 * @param int $post_id First argument.
	 */
	public function addify_shortcode_setting( $post_id ) {

		$qof_rule_id = $post_id;
		echo '<b>[qof_quick_order_form id =' . esc_attr( $qof_rule_id->ID ) . ']</b>';
		echo '<br>';
		?>
		<label><?php esc_html_e('Shortcode will only be applicable to the existing pages or newly created pages.' , 'qof_form_order'); ?></label>
		<?php
	}
}

/**
* Class Object.
*/
if ( class_exists( 'Addify_Qof_Admin' ) ) {
	$addify_qof_admin = new addify_qof_admin();
}
