<?php
/**
 * Plugin Name:       Addify Quick Order Table
 * Plugin URI:        https://addify.store/product/woocommerce-wholesale-quick-order-form/
 * Description:       Create quick order table according to user roles and settings.
 * Version:           1.2.0
 * Author:            Addify
 * Developed By:      Addify
 * Author URI:        https://www.addif.store
 * Support:           https://www.addify.store
 * License:           GNU General Public License v3.0
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 * Domain Path:       /languages
 * Text Domain:       qof_form_order
 * WC requires at least: 3.0.9
 * WC tested up to: 9.*.*
 *
 * @package : addify-quick-order-table
 */

if ( ! defined( 'ABSPATH' ) ) {
		exit;
}

/**
 * Creating Class.
 */
class Addify_QOForm_Main {

	/**
	 * Constructor.
	 */
	public function __construct() {

		$this->plugin_global_variables();
		/**
		* Calling Functions.
		*/
		add_action( 'wp_loaded', array( $this, 'quick_order_form_initial' ) );
		if ( is_admin() ) {

			include_once QOF_PLUGIN_DIR . 'class-addify-qof-admin.php';
			
		} else {

			include_once QOF_PLUGIN_DIR . 'class-addify-qof-frontend.php';

		}
		include QOF_PLUGIN_DIR . 'class-addify-qof-ajax-controller.php';

		add_action('before_woocommerce_init', array( $this, 'qof_HOPS_Compatibility' ));

		add_action( 'plugins_loaded', array( $this, 'qof_checks' ) ); 
	}

	public function qof_HOPS_Compatibility() {

		if (class_exists(\Automattic\WooCommerce\Utilities\FeaturesUtil::class)) {
			\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility('custom_order_tables', __FILE__, true);
		}
	}

	public function qof_checks() {

		// Check the installation of WooCommerce module if it is not a multi site.
		if ( ! is_multisite() ) {
			if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {
				
				add_action( 'admin_notices', array( $this, 'qof_check_wocommerce' ));
			}
		}
	}

	public function qof_check_wocommerce() {


		// Deactivate the plugin.
		deactivate_plugins(__FILE__);

		$qof_woo_check = '<div id="message" class="error">
            <p><strong>' . __( 'Addify Quick Order Table plugin is inactive.', 'qof_form_order' ) . '</strong> The <a href="http://wordpress.org/extend/plugins/woocommerce/">WooCommerce plugin</a> ' . __( 'must be active for this plugin to work. Please install &amp; activate WooCommerce.', 'qof_form_order' ) . ' »</p></div>';
		echo wp_kses_post( $qof_woo_check );
	}

	/**
	 * Defining Global Variables.
	 */
	public function plugin_global_variables() {

		if ( ! defined( 'QOF_URL' ) ) {
			define( 'QOF_URL', plugin_dir_url( __FILE__ ) );
		}

		if ( ! defined( 'QOF_BASENAME' ) ) {
			define( 'QOF_BASENAME', plugin_basename( __FILE__ ) );
		}

		if ( ! defined( 'QOF_PLUGIN_DIR' ) ) {
			define( 'QOF_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
		}
	}

	/**
	 * Loading Text Domain.
	 */
	public function quick_order_form_initial() {
		if ( function_exists( 'load_plugin_textdomain' ) ) {
				load_plugin_textdomain( 'qof_form_order', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
		}
	}
}

/**
* Creating Class Object.
*/
if ( class_exists( 'Addify_QOForm_Main' ) ) {
		$addify_qoform_main = new addify_qoform_main();
}
